Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RootCmd = &cobra.Command{ Short: "BitBucket Command Line Interface", Long: `BitBucket Command Line Interface is a tool to manage your BitBucket. You can manage your pull requests, issues, profiles, etc.`, Run: func(cmd *cobra.Command, args []string) { fmt.Println("bb requires a command:") for _, command := range cmd.Commands() { fmt.Println(command.Name()) } }, }
RootCmd represents the base command when called without any subcommands
Functions ¶
Types ¶
type RootOptions ¶
type RootOptions struct {
ConfigFile string `mapstructure:"-"`
LogDestination string `mapstructure:"-"`
ProfileName string `mapstructure:"-"`
OutputFormat flags.EnumFlag `mapstructure:"-"`
DryRun bool `mapstructure:"-"`
Verbose bool `mapstructure:"-"`
Debug bool `mapstructure:"-"`
}
RootOptions describes the options for the application
var CmdOptions RootOptions
CmdOptions contains the options for the application
Click to show internal directories.
Click to hide internal directories.